==> ckeditor5_mentions-1.1.0.tar.gz: ckeditor5_mentions/src/Plugin/CKEditor5Plugin/Mentions.php <==
<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_mentions\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * CKEditor 5 Mentions plugin.
 *
 * @internal
 *   Plugin classes are internal.
 */
class Mentions extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'dropdown_limit' => 10,
      'commit_keys' => [13, 32],
      'mention_feeds_enabled' => [],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['allow_resize'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow the user to resize images'),
      '#default_value' => $this->configuration['allow_resize'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    // Match the config schema structure at ckeditor5.plugin.ckeditor5_imageResize.
    $form_value = $form_state->getValue('allow_resize');
    $form_state->setValue('allow_resize', (bool) $form_value);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['allow_resize'] = $form_state->getValue('allow_resize');
  }

}

==> ckeditor5_mentions-2.0.0.tar.gz: ckeditor5_mentions/src/Plugin/CKEditor5Plugin/Mentions.php <==
<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_mentions\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * CKEditor 5 Mentions plugin.
 *
 * @internal
 *   Plugin classes are internal.
 */
class Mentions extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'dropdown_limit' => 10,
      'commit_keys' => [13, 32],
      'mention_feeds_enabled' => [],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['allow_resize'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow the user to resize images'),
      '#default_value' => $this->configuration['allow_resize'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    // Match the config schema structure at
    // ckeditor5.plugin.ckeditor5_imageResize.
    $form_value = $form_state->getValue('allow_resize');
    $form_state->setValue('allow_resize', (bool) $form_value);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['allow_resize'] = $form_state->getValue('allow_resize');
  }

}
